@@ -1,6 +1,4 @@
 package Mojolicious::Plugin::RoutesAuthDBI::POS::Pg;
-use Mojo::Base 'DBIx::POS';
-__PACKAGE__->instance (__FILE__);
 
 =pod
 
@@ -378,12 +376,13 @@ L<DBIx::POS>
 
 =item * B<> 
 
-=name
+=name тест
 
 =desc
 
 =sql
 
+  ыудусе * акщь тест!ж
 
 =back
 
